from .preamble import EdgeShape
from collections import namedtuple

tiling_types = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
    20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 36, 37, 38, 39,
    40, 41, 42, 43, 44, 45, 46, 47, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59,
    61, 62, 64, 66, 67, 68, 69, 71, 72, 73, 74, 76, 77, 78, 79, 81, 82, 83, 84,
    85, 86, 88, 90, 91, 93]
 
Tile = namedtuple('Tile',
    [
            "num_params",
            "num_aspects",
            "num_vertices",
            "num_edge_shapes",
            "edge_shapes",
            "edge_orientations",
            "edge_shape_ids",
            "default_params",
            "vertex_coeffs",
            "translation_coeffs",
            "aspect_coeffs",
            "coloring"
    ]
    )

class TilingTypeData:

    es_00 = [ EdgeShape.J, EdgeShape.J, EdgeShape.J ]
    es_01 = [ EdgeShape.S, EdgeShape.J, EdgeShape.S, EdgeShape.S, EdgeShape.S ]
    es_02 = [ EdgeShape.S, EdgeShape.J, EdgeShape.J, EdgeShape.S ]
    es_03 = [ EdgeShape.S, EdgeShape.J, EdgeShape.S, EdgeShape.J ]
    es_04 = [ EdgeShape.S, EdgeShape.S, EdgeShape.S ]
    es_05 = [ EdgeShape.S, EdgeShape.J ]
    es_06 = [ EdgeShape.J ]
    es_07 = [ EdgeShape.S ]
    es_08 = [ EdgeShape.U, EdgeShape.J ]
    es_09 = [ EdgeShape.U, EdgeShape.S, EdgeShape.S ]
    es_10 = [ EdgeShape.J, EdgeShape.I ]
    es_11 = [ EdgeShape.S, EdgeShape.I, EdgeShape.S ]
    es_12 = [ EdgeShape.I, EdgeShape.J ]
    es_13 = [ EdgeShape.I, EdgeShape.S ]
    es_14 = [ EdgeShape.U ]
    es_15 = [ EdgeShape.I ]
    es_16 = [ EdgeShape.S, EdgeShape.J, EdgeShape.J ]
    es_17 = [ EdgeShape.J, EdgeShape.J, EdgeShape.I ]
    es_18 = [ EdgeShape.S, EdgeShape.S, EdgeShape.J, EdgeShape.S ]
    es_19 = [ EdgeShape.S, EdgeShape.S, EdgeShape.J, EdgeShape.I ]
    es_20 = [ EdgeShape.J, EdgeShape.J, EdgeShape.S ]
    es_21 = [ EdgeShape.S, EdgeShape.I, EdgeShape.I ]
    es_22 = [ EdgeShape.J, EdgeShape.I, EdgeShape.I ]
    es_23 = [ EdgeShape.J, EdgeShape.J ]
    es_24 = [ EdgeShape.I, EdgeShape.I ]
    es_25 = [ EdgeShape.J, EdgeShape.S ]
    es_26 = [ EdgeShape.S, EdgeShape.S, EdgeShape.S, EdgeShape.S ]
    es_27 = [ EdgeShape.J, EdgeShape.S, EdgeShape.S ]
    es_28 = [ EdgeShape.I, EdgeShape.S, EdgeShape.I, EdgeShape.S ]
    es_29 = [ EdgeShape.J, EdgeShape.I, EdgeShape.S ]
    es_30 = [ EdgeShape.I, EdgeShape.I, EdgeShape.I, EdgeShape.S ]
    es_31 = [ EdgeShape.S, EdgeShape.S ]
    es_32 = [ EdgeShape.S, EdgeShape.I ]
    es_33 = [ EdgeShape.U, EdgeShape.I ]
    es_34 = [ EdgeShape.U, EdgeShape.S ]
    es_35 = [ EdgeShape.I, EdgeShape.I, EdgeShape.I ]
    es_36 = [ EdgeShape.I, EdgeShape.S, EdgeShape.I ]
    es_37 = [ EdgeShape.I, EdgeShape.S, EdgeShape.S ]

    esi_00 = [ 0, 1, 2, 0, 1, 2 ]
    esi_01 = [ 0, 0, 1, 2, 2, 1 ]
    esi_02 = [ 0, 1, 0, 2, 1, 2 ]
    esi_03 = [ 0, 1, 2, 3, 1, 4 ]
    esi_04 = [ 0, 1, 2, 2, 1, 3 ]
    esi_05 = [ 0, 1, 2, 3, 1, 3 ]
    esi_06 = [ 0, 0, 1, 1, 2, 2 ]
    esi_07 = [ 0, 1, 1, 0, 1, 1 ]
    esi_08 = [ 0, 0, 0, 0, 0, 0 ]
    esi_09 = [ 0, 1, 2, 0, 2, 1 ]
    esi_10 = [ 0, 1, 0, 0, 1, 0 ]
    esi_11 = [ 0, 1, 2, 2, 1, 0 ]
    esi_12 = [ 0, 1, 1, 1, 1, 0 ]
    esi_13 = [ 0, 1, 1, 2, 2 ]
    esi_14 = [ 0, 0, 1, 2, 1 ]
    esi_15 = [ 0, 1, 2, 3, 2 ]
    esi_16 = [ 0, 1, 2, 1, 2 ]
    esi_17 = [ 0, 1, 1, 1, 1 ]
    esi_18 = [ 0, 1, 2, 0 ]
    esi_19 = [ 0, 1, 1, 0 ]
    esi_20 = [ 0, 0, 0, 0 ]
    esi_21 = [ 0, 1, 0 ]
    esi_22 = [ 0, 1, 0, 1 ]
    esi_23 = [ 0, 1, 0, 2 ]
    esi_24 = [ 0, 0, 1, 1 ]
    esi_25 = [ 0, 1, 2, 3 ]
    esi_26 = [ 0, 0, 1, 2 ]
    esi_27 = [ 0, 1, 2 ]
    esi_28 = [ 0, 0, 1 ]
    esi_29 = [ 0, 0, 0 ]

    eo_00 = [ False, False, False, False, False, False, False, True, False, True, False, True ]
    eo_01 = [ False, False, True, True, False, False, False, False, True, True, False, True ]
    eo_02 = [ False, False, False, False, True, True, False, False, False, True, True, True ]
    eo_03 = [ False, False, False, False, False, False, False, False, False, True, False, False ]
    eo_04 = [ False, False, False, False, False, False, True, True, False, True, False, False ]
    eo_05 = [ False, False, False, False, False, False, False, False, True, True, True, True ]
    eo_06 = [ False, False, False, True, False, False, False, True, False, False, False, True ]
    eo_07 = [ False, False, False, False, False, False, False, False, False, False, False, False ]
    eo_08 = [ False, False, False, False, True, True, False, False, False, False, True, True ]
    eo_09 = [ False, False, False, False, True, True, False, True, False, True, True, False ]
    eo_10 = [ False, False, False, False, False, False, False, True, True, False, True, False ]
    eo_11 = [ False, False, False, False, True, True, False, True, True, False, True, False ]
    eo_12 = [ False, False, False, False, False, False, True, False, True, False, True, False ]
    eo_13 = [ False, False, False, False, False, True, True, True, True, False, True, False ]
    eo_14 = [ False, False, False, False, True, False, False, False, False, False, True, False ]
    eo_15 = [ False, False, False, False, False, True, False, False, False, True ]
    eo_16 = [ False, False, True, True, False, False, False, False, False, True ]
    eo_17 = [ False, False, False, False, False, False, False, False, False, True ]
    eo_18 = [ False, False, True, False, False, False, False, False, True, False ]
    eo_19 = [ False, False, False, False, False, False, True, True, True, True ]
    eo_20 = [ False, False, False, False, False, True, True, True, True, False ]
    eo_21 = [ False, False, False, False, False, False, False, True ]
    eo_22 = [ False, False, False, False, False, True, False, True ]
    eo_23 = [ False, False, False, False, True, False, True, False ]
    eo_24 = [ False, False, False, True, False, False, False, True ]
    eo_25 = [ False, False, True, False, True, True, False, True ]
    eo_26 = [ False, False, True, False, False, False, True, False ]
    eo_27 = [ False, False, False, False, False, True ]
    eo_28 = [ False, False, False, False, True, False ]
    eo_29 = [ False, False, False, False, False, True, False, False ]
    eo_30 = [ False, False, False, False, False, True, True, True ]
    eo_31 = [ False, False, True, True, False, False, True, True ]
    eo_32 = [ False, False, False, False, True, True, False, False ]
    eo_33 = [ False, False, False, False, False, False, False, False ]
    eo_34 = [ False, False, False, False, True, True, True, True ]
    eo_35 = [ False, False, True, True, False, False, False, False ]
    eo_36 = [ False, False, False, True, False, False, False, False ]
    eo_37 = [ False, False, False, False, False, True, True, False ]
    eo_38 = [ False, False, False, False, True, False, False, False ]
    eo_39 = [ False, False, True, True, False, True, True, False ]
    eo_40 = [ False, False, False, True, True, True, True, False ]
    eo_41 = [ False, False, False, False, False, False ]
    eo_42 = [ False, False, True, True, False, False ]
    eo_43 = [ False, False, False, True, False, False ]
    eo_44 = [ False, False, True, False, False, False ]

    dp_00 = [ 0.12239750492, 0.5, 0.143395479017, 0.625 ]
    dp_01 = [ 0.12239750492, 0.5, 0.225335752741, 0.225335752741 ]
    dp_02 = [ 0.12239750492, 0.5, 0.225335752741, 0.625 ]
    dp_03 = [ 0.12239750492, 0.5, 0.315470053838, 0.5, 0.315470053838, 0.5 ]
    dp_04 = [ 0.12239750492, 0.5, 0.225335752741, 0.225335752741, 0.5 ]
    dp_05 = [ 0.12239750492, 0.5, 0.225335752741, 0.625, 0.5 ]
    dp_06 = [ 0.6, 0.196416770201 ]
    dp_07 = [ 0.12239750492, 0.5, 0.225335752741 ]
    dp_08 = [  ]
    dp_09 = [ 0.12239750492, 0.225335752741 ]
    dp_10 = [ 0.12239750492, 0.225335752741, 0.5 ]
    dp_11 = [ 0.12239750492, 0.225335752741, 0.225335752741 ]
    dp_12 = [ 0.216506350946 ]
    dp_13 = [ 0.104512294489, 0.65 ]
    dp_14 = [ 0.230769230769, 0.5, 0.225335752741 ]
    dp_15 = [ 0.230769230769, 0.5, 0.225335752741, 0.5 ]
    dp_16 = [ 0.230769230769, 0.225335752741 ]
    dp_17 = [ 0.141304, 0.465108, 0.534891 ]
    dp_18 = [ 0.452827026611, 0.5 ]
    dp_19 = [ 0.366873818946 ]
    dp_20 = [ 0.230769230769 ]
    dp_21 = [ 0.230769230769, 0.5 ]
    dp_22 = [ 0.5, 0.102564102564 ]
    dp_23 = [ 0.230769230769, 0.869565217391 ]
    dp_24 = [ 0.5, 0.230769230769, 0.5, 0.5 ]
    dp_25 = [ 0.230769230769, 0.5, 0.230769230769 ]
    dp_26 = [ 0.5, 0.5, 0.6 ]
    dp_27 = [ 0.5, 0.102564102564, 0.102564102564 ]
    dp_28 = [ 0.230769230769, 0.230769230769 ]
    dp_29 = [ 0.5 ]
    dp_30 = [ 0.105263157895 ]
    dp_31 = [ 0.196416770201 ]
    dp_32 = [ 0.5, 0.196416770201 ]

    tvc_00 = [
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3.9, 0, 0, 0, 0.1, 0, 5, 0, 0, -2.5, 3.9, 0, 5.5, 0, -0.4, 0, 5, 0, -4, 0.5, 3.9, 0, 0, 0, 0.1, 0, 5, 0, 0, -1.5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -5.5, 0, 0.5, 0, 0, 0, 4, -2 ]
    tvc_01 = [
        3.9, 0, 0, 0, 0.1, 0, 5, 0, 0, -2.5, 3.9, 0, 0, 3.5, -0.4, 0, 5, 0, 0, -2, 3.9, 0, 0, 0, 0.1, 0, 5, 0, 0, -1.5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -3.5, 0, 0.5, 0, 0, 0, 0, 0.5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ]
    tvc_02 = [
        0, 0, -3.5, 0, 0.5, 0, 0, 0, 4, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3.9, 0, 0, 0, 0.1, 0, 5, 0, 0, -2.5, 3.9, 0, 3.5, 0, -0.4, 0, 5, 0, 4, -4.5, 3.9, 0, 0, 0, 0.1, 0, 5, 0, 0, -1.5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1 ]
    tvc_03 = [
        0, 0, -2.5, 0, 0, 0, 0.5, 0, 0, 0, 3, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3.9, 0, 0, 0, 0, 0, 0.1, 0, 5, 0, 0, 0, 0, -2.5, 3.9, 0, 0, 0, 2.5, 0, -0.4, 0, 5, 0, 0, 0, 3, -3.5, 3.9, 0, 0, 0, 0, 0, 0.1, 0, 5, 0, 0, 0, 0, -1.5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1 ]
    tvc_04 = [
        3.9, 0, 0, 3.5, 0, -0.4, 0, 5, 0, 0, 5, -4.5, 3.9, 0, 0, 0, 0, 0.1, 0, 5, 0, 0, 0, -1.5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -3.5, 0, 0, 0.5, 0, 0, 0, 0, 0, 0.5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3.9, 0, 0, 0, 0, 0.1, 0, 5, 0, 0, 0, -2.5 ]
    tvc_05 = [
        3.9, 0, 3.5, 0, 0, -0.4, 0, -5, 0, 4, 0, 0.5, 3.9, 0, 0, 0, 5, -2.4, 0, 5, 0, 0, 0, -1.5, 0, 0, 0, 0, 5, -2.5, 0, 0, 0, 0, 0, 1, 0, 0, -3.5, 0, 0, 0.5, 0, 0, 0, 4, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3.9, 0, 0, 0, 0, 0.1, 0, -5, 0, 0, 0, 2.5 ]
    tvc_06 = [
        0, 0, 0, 0, 0, 0, 0, 0, 0.5, 0, 0, -0.288675134595, 0, 0, 1, 0, 0, 0, 2.5, 1.12583302492, -0.721132486541, -1.44337567297, 1.95, 1.06036297108, 5, 0, -2.5, 0, 3.9, 0.1, 2.5, -1.12583302492, -1.27886751346, 1.44337567297, 1.95, -0.671687836487 ]
    tvc_07 = [
        0, 0, 0, 0, 0, 0, 0, 0, 3.9, 0, 0, 0.1, 0, 5, 0, -2.5, 3.9, 0, 3.5, -0.4, 0, 5, 0, -2, 3.9, 0, 0, 0.1, 0, 5, 0, -1.5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -3.5, 0.5, 0, 0, 0, 0.5 ]
    tvc_08 = [
        1, 0, 0.5, 0.866025403784, -0.5, 0.866025403784, -1, 0, -0.5, -0.866025403784, 0.5, -0.866025403784 ]
    tvc_09 = [
        0, 0, 0, 0, 0, 0, 3.9, 0, 0.1, 0, 0, 0, 3.9, 3.5, -0.4, 0, 0, 0.5, 3.9, 0, 0.1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, -3.5, 0.5, 0, 0, 0.5 ]
    tvc_10 = [
        0, 0, 0, 0, 0, 0, 0, 0, 3.9, 0, 0, 0.1, 0, 0, 0, 0, 3.9, 3.5, 0, -0.4, 0, 0, 5, -2, 3.9, 0, 0, 0.1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, -3.5, 0, 0.5, 0, 0, 5, -2 ]
    tvc_11 = [
        3.9, 3.5, -0.4, 0, 0, 0.5, 3.9, 0, 0.1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, -3.5, 0.5, 0, 0, 0.5, 0, 0, 0, 0, 0, 0, 3.9, 0, 0.1, 0, 0, 0 ]
    tvc_12 = [
        0, -3.5, 0, 0.5, 0, 0, 0, 0.5, 0, 0, 0, 0, 0, 0, 0, 0, 3.9, 0, 0, 0.1, 0, 0, 0, 0, 3.9, 0, 3.5, -0.4, 0, 0, 0, 0.5, 3.9, 0, 0, 0.1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1 ]
    tvc_13 = [
        0, 0.5, 0, -0.288675134595, 0, 1, 0, 0, 1.15470053838, 0.75, 2, 0.144337567297, 0, 0.5, 4, 0, -1.15470053838, 0.25, 2, 0.144337567297, 0, 0, 0, 0 ]
    tvc_14 = [
        0, 0, 1, 0, 0, 0, 0, 5, -2.5, 5.1, 0, -0.1, -1.47224318643, 2.5, -1.22113248654, 2.55, 1.44337567297, -0.771687836487, 0, 0, 0, 0, 0, 0, 0, 0, 0.5, 0, 0, -0.866025403784 ]
    tvc_15 = [
        3.9, 0, 0, 0.1, 0, 5, 0, -2.5, 3.9, 0, 3.5, -0.4, 0, 5, 0, -2, 3.9, 0, 0, 0.1, 0, 5, 0, -1.5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0 ]
    tvc_16 = [
        3.9, 0, 0, 0, 0.1, 0, 5, 0, 0, -2.5, 3.9, 0, 3.5, 0, -0.4, 0, 5, 0, 4, -4, 3.9, 0, 0, 0, 0.1, 0, 5, 0, 0, -1.5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ]
    tvc_17 = [
        3.9, 0, 0.1, 0, 0, 0, 3.9, 3.5, -0.4, 0, 0, 0.5, 3.9, 0, 0.1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0 ]
    tvc_18 = [
        0, 0, 5, -2.5, 0, 0, 0, 1, 0, 0, -5, 2.5, 0, 10, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0, 3.9, 0, 0, 0.1, 0, -5, 0, 2.5, 3.9, 0, 5, -2.4, 0, 5, 0, -1.5 ]
    tvc_19 = [
        0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1.95, 2.5, -0.95, -1.95, 2.5, -1.05, 3.9, 0, 0.1, 0, 5, -2, 1.95, -2.5, 1.55, 1.95, 2.5, -0.45 ]
    tvc_20 = [
        0, -1, 0, 0, 0, 1, 0, 0, 4.95, 0.55, 4.95, 0.55, 0, 0, 9.9, 0.1, -4.95, -0.55, 4.95, 0.55 ]
    tvc_21 = [
        0, 1, 0, 0, 2.925, 0.075, 1.68874953738, 0.0433012701892, 0, 0, 0, 0, -2.925, 1.425, 1.68874953738, -0.822724133595 ]
    tvc_22 = [
        1, 0, 0.75, 0.433012701892, 0, 0, 0.75, -0.433012701892 ]
    tvc_23 = [
        0.5, 0, 0, 0.866025403784, -0.5, 0, 0, -0.866025403784 ]
    tvc_24 = [
        0, 0.57735026919, -1, 0, 1, 0 ]
    tvc_25 = [
        0, 0, 0, 0, 0, 0, 3.9, 0, 0.1, 0, 5, -2.5, 3.9, 0, 0.1, 0, 5, -1.5, 0, 0, 0, 0, 0, 1 ]
    tvc_26 = [
        5, 0, -2, 0, -3.9, -0.1, 0, 0, 1, 0, 0, 0, 5, 0, -2, 0, 3.9, 0.1, 0, 0, 0, 0, 0, 0 ]
    tvc_27 = [
        0, 0, 1, 0, 0, 0, 0, -3.45, 4, 3.9, 0, 0.1, 0, 3.45, -3, 3.9, 0, 0.1, 0, 0, 0, 0, 0, 0 ]
    tvc_28 = [
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 5, 0, 0, 0, -1.5, 0, 3.9, 0, 0, 0.1, 0, 0, 5, 0, -2.5, 0, 0, 0, 5, -1.5 ]
    tvc_29 = [
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -5, 3.9, 2.6, 3.9, 0, 0, 0.1, 0, -5, 0, 2.5, 3.9, 0, 0, 0.1 ]
    tvc_30 = [
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -10, 0, 0, 5, 0, 10, 0, -4, 10, 0, 10, -10, 0, 10, 0, -5, 0, 0, 10, -5 ]
    tvc_31 = [
        0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 3.9, 0.1, 0, 0, 3.9, 0.1 ]
    tvc_32 = [
        0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0.5, 0, 0, 3.9, 0.1, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, -2, 0, -3.9, 0, -0.1 ]
    tvc_33 = [
        0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 3.9, 0, 0.1, 0, 0, 0, 3.9, 0, 0.1, 0, 3.9, 0.1 ]
    tvc_34 = [
        1, 0, 1, 1, 0, 1, 0, 0 ]
    tvc_35 = [
        1.8, 0.1, 0, 0, 0, 1, 0, 1, 0, 0, -1.8, 1.9, 0, 0, 0, 0 ]
    tvc_36 = [
        3.8, 0.1, 0, 0, 0, 0, -3.8, 0.9, -3.8, -0.1, 0, 0, 0, 0, 3.8, -0.9 ]
    tvc_37 = [
        0, 0, 0.57735026919, 0, 0, 1 ]
    tvc_38 = [
        0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 3.9, 0.1 ]
    tvc_39 = [
        0.5, 0.5, 0, 0, 1, 0 ]
    tvc_40 = [
        0, 1, 0, 0, 0, 0.5, 3.9, 0.1, 0, 0, 0, 0 ]
    tvc_41 = [
        0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 5, 0, -2, 0, 3.9, 0.1 ]
    tvc_42 = [
        1, 0, -0.5, 0.866025403784, -0.5, -0.866025403784 ]

    tc_00 = [ 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 3.9, 0, 5.5, 0, -0.4, 0, 5, 0, -4, -0.5 ]
    tc_01 = [ 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7.8, 0, 3.5, 3.5, -0.8, 0, 0, 0, 0, 0 ]
    tc_02 = [ 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, -7.8, 0, -7, 0, 0.8, 0, 0, 0, 0, -1 ]
    tc_03 = [ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, -7.8, 0, -2.5, 0, -2.5, 0, 0.8, 0, -10, 0, 3, 0, -3, 4 ]
    tc_04 = [ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -15.6, 0, -7, -7, 0, 1.6, 0, 0, 0, 0, 0, -2 ]
    tc_05 = [ 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, -3, 7.8, 0, 7, 0, 0, -0.8, 0, 0, 0, 0, 0, 0 ]
    tc_06 = [ -2.5, -3.37749907476, 0.663397459622, 4.33012701892, -1.95, -3.08108891325, -2.5, 3.37749907476, 2.33660254038, -4.33012701892, -1.95, 2.11506350946 ]
    tc_07 = [ 0, 0, 0, 0, 0, 0, 0, -1, 7.8, 0, 7, -0.8, 0, 0, 0, 0 ]
    tc_08 = [ 1.5, 0.866025403784, 1.5, -0.866025403784 ]
    tc_09 = [ 1.5, 0.866025403784, 0, 1.73205080757 ]
    tc_10 = [ 0, 0, 0, 0, 0, -1, 3.9, 3.5, -0.4, 0, 0, -0.5 ]
    tc_11 = [ 0, 0, 0, 0, 0, 0, 0, -1, 7.8, 7, 0, -0.8, 0, 0, 0, 0 ]
    tc_12 = [ 3.9, 3.5, -0.4, 0, 0, 0.5, 3.9, 3.5, -0.4, 0, 0, -0.5 ]
    tc_13 = [ 0, 0, 0, 0, 0, 0, 0, -1, -7.8, -3.5, -3.5, 0.8, 0, 0, 0, 0 ]
    tc_14 = [ 0, 0, -4, -0.866025403784, 3.46410161514, 0.75, -2, -0.433012701892 ]
    tc_15 = [ 4.4167295593, -2.5, 2.66339745962, -2.55, -4.33012701892, 1.34903810568, 0, -5, 2.5, -5.1, 0, -1.63205080757 ]
    tc_16 = [ -7.8, 0, -3.5, 0.3, 0, 0, 0, -0.5, -7.8, 0, -3.5, 0.3, 0, 0, 0, 0.5 ]
    tc_17 = [ 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7.8, 0, 3.5, 0, -0.3, 0, 10, 0, 4, -7.5 ]
    tc_18 = [ 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 15.6, 0, 7, 0, -0.6, 0, 0, 0, 0, 0 ]
    tc_19 = [ 0, 0, 0, 0, 0, 0, 0, 1, -15.6, 0, -7, 0.6, 0, 0, 0, 0 ]
    tc_20 = [ 0, 0, 0, 0, 0, 1, -7.8, -3.5, 0.3, 0, 0, 0.5 ]
    tc_21 = [ 0, 0, 0, 0, 0, 10, 0, -3, -7.8, 0, -10, 4.8, 0, 0, 0, 0 ]
    tc_22 = [ -3.9, 5, -3.1, -3.9, -5, 1.9, -3.9, -5, 1.9, 3.9, -5, 3.1 ]
    tc_23 = [ 9.9, 1.1, -9.9, -1.1, -9.9, -1.1, -9.9, -1.1 ]
    tc_24 = [ 0, 0, 0, 1.73205080757, 0, 1.5, 0, -0.866025403784 ]
    tc_25 = [ -1.5, 0.866025403784, -1.5, -0.866025403784 ]
    tc_26 = [ 0, 1.73205080757, 1.5, -0.866025403784 ]
    tc_27 = [ -1, 1.73205080757, 1, 1.73205080757 ]
    tc_28 = [ 1, 1.73205080757, -1, 1.73205080757 ]
    tc_29 = [ 1, 1.73205080757, 2, 0 ]
    tc_30 = [ 0, 0, 0, 0, 0, -1, 3.9, 0, 0.1, 0, 5, -2.5 ]
    tc_31 = [ 0, 0, 0, 0, 0, -1, 7.8, 0, 0.2, 0, 0, 0 ]
    tc_32 = [ 0, 0, 0, 0, -7.8, -0.2, 0, 0, 1, 0, 0, 0 ]
    tc_33 = [ 0, -6.9, 8, 0, 0, 0, 0, -3.45, 4, -3.9, 0, -0.1 ]
    tc_34 = [ -5, 0, -5, 0, 5, 0, -3.9, 0, -5, 1.4, -5, 0, 0, 0, 1.5, 0, -3.9, 0, 0, -0.1 ]
    tc_35 = [ 0, 0, 0, 0, 0, -1, 7.8, 0, 0.2, 0, 10, -5 ]
    tc_36 = [ 0, 0, 0, 0, -7.8, 0, 0, -0.2, 0, 0, 3.9, 1.1, 0, 0, 0, 0 ]
    tc_37 = [ -15.6, 0, -0.4, 0, 0, 0, 0, 0, 0, 0, 0, -1 ]
    tc_38 = [ 0, 0, 0, 0, -20, 0, -20, 20, 0, 0, 0, -2, 0, 0, 0, 0 ]
    tc_39 = [ 0, 2, 0, 0, 0, 0, -7.8, -0.2 ]
    tc_40 = [ 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -7.8, -7.8, -0.4 ]
    tc_41 = [ -7.8, 0, -0.2, 0, 0, 0, -3.9, 0, -0.1, 0, 3.9, 1.1 ]
    tc_42 = [ 0, 2, 2, 0 ]
    tc_43 = [ 0, 0, 0, 4, 0, -2, 0, 2 ]
    tc_44 = [ 0, 0, -7.6, 1.8, 7.6, 0.2, -7.6, 1.8 ]
    tc_45 = [ 1, 1, 1, -1 ]
    tc_46 = [ 1, 0, 0, 1 ]
    tc_47 = [ 0, 0, -3.9, -0.1, 0, 1, 0, 0 ]
    tc_48 = [ 0, 0, -3.9, -0.1, 0, 2, 0, 0 ]
    tc_49 = [ 0, -3.45, 4, -3.9, 0, -0.1, 0, -3.45, 4, 3.9, 0, 0.1 ]
    tc_50 = [ 3.8, 0.1, -3.8, 0.9, -3.8, -0.1, -3.8, 0.9 ]
    tc_51 = [ 0, 2, -1.73205080757, 1 ]
    tc_52 = [ 0, 2, 0, 0, 0, 1, 3.9, 0.1 ]
    tc_53 = [ 0, 1, -1, 0 ]
    tc_54 = [ -1, 1, -2, 0 ]
    tc_55 = [ 0, 1, 1, 0 ]
    tc_56 = [ 0, 0.5, -3.9, -0.1, 0, -0.5, -3.9, -0.1 ]
    tc_57 = [ -5, 0, 2, 0, -3.9, -0.1, -5, 0, 3, 0, -3.9, -0.1 ]
    tc_58 = [ 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 7.8, 0.2 ]
    tc_59 = [ 0, 1, 0, 0, 0, 0, 7.8, 0.2 ]
    tc_60 = [ -1.5, 2.59807621135, -3, 0 ]
    tc_61 = [ 0, -0.5, -3.9, -0.1, 0, 0.5, -3.9, -0.1 ]

    ac_00 = [
        0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0 ]
    ac_01 = [
        0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 7.8, 0, 0, 3.5, -0.3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, -0.5 ]
    ac_02 = [
        0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -3.9, 0, -3.5, 0, 0.4, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 5, 0, 4, -4.5 ]
    ac_03 = [
        0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.5, 0, 0, 0, 0.5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 3, 0, 0, -1 ]
    ac_04 = [
        0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 7.8, 0, 0, 3.5, 0, -0.3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 10, 0, 0, 5, -6, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, -3.5, 0, 0, 0.5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -0.5, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, -7.8, 0, -3.5, -3.5, 0, 0.8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 10, 0, 0, 5, -7.5 ]
    ac_05 = [
        0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 7.8, 0, 3.5, 0, 5, -2.8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 4, 0, -1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 3.9, 0, 0, 0, 5, -2.4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, -1.5, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 3.9, 0, 3.5, 0, 0, -0.4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -5, 0, 4, 0, 0.5 ]
    ac_06 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -0.5, 0, 0, -0.866025403784, 0, 0, 0.5, 0, 0, 0.866025403784, 0, 0, -0.5, 0, 0, -0.866025403784, 0, 0, -0.5, 0, 0, 0.866025403784, 0, 0, 1, 0, 0, -0.866025403784, 0, 0, -0.5, 0, 0, 0 ]
    ac_07 = [
        0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 7.8, 0, 3.5, -0.3, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, -0.5 ]
    ac_08 = [
        1, 0, 0, 0, 1, 0 ]
    ac_09 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0 ]
    ac_10 = [
        0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 7.8, 3.5, 0, -0.3, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 5, -2 ]
    ac_11 = [
        0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, -3.5, 0, 0.5, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0.5 ]
    ac_12 = [
        0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0.5, 0, 0.866025403784, 0, 0.5, 0, 0.866025403784, 0, -0.5, 0, -0.866025403784, 0, -0.5, 0, -0.866025403784, 0, 0.5, 0, 0.866025403784, 0, -0.5, 0, -0.866025403784 ]
    ac_13 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0.5, 0, 0, 0.866025403784, 0, 0, 1, 0, 0, -0.866025403784, 0, 0, 0.5, 0, 0, 0, 0, 0, -0.5, 0, 0, 0.866025403784, 0, 0, 1.5, 0, 0, -0.866025403784, 0, 0, -0.5, 0, 0, -0.866025403784, 0, 0, -1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, -1.73205080757, 0, 0, -0.5, 0, 0, -0.866025403784, 0, 0, 0, 0, 0, 0.866025403784, 0, 0, -0.5, 0, 0, -1.73205080757, 0, 0, 0.5, 0, 0, -0.866025403784, 0, 0, -0.5, 0, 0, 0.866025403784, 0, 0, 0.5, 0, 0, -0.866025403784 ]
    ac_14 = [
        0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0 ]
    ac_15 = [
        0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 7.8, 0, 3.5, 0, -0.3, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 10, 0, 4, -6.5 ]
    ac_16 = [
        0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 7.8, 0, 3.5, 0, -0.3, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 10, 0, 4, -6.5, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 15.6, 0, 7, 0, -0.6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 7.8, 0, 3.5, 0, -0.3, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 10, 0, 4, -6.5 ]
    ac_17 = [
        0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 0, -7.8, 0, -3.5, 0.3, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, -0.5, 0, 0, 0, 1, 0, 0, 0, 0, -7.8, 0, -3.5, 0.3, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0.5 ]
    ac_18 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 1 ]
    ac_19 = [
        0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 10, 0, -3, 0, 0, 0, 1, 0, 0, 0, 0, -3.9, 0, -5, 2.4, 0, 0, 0, 0, 0, 0, 0, -1, 0, 5, 0, -1.5, 0, 0, 0, -1, 0, 0, 0, 0, 3.9, 0, 5, -2.4, 0, 0, 0, 0, 0, 0, 0, 1, 0, 5, 0, -1.5 ]
    ac_20 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 1, 0, 0, 0, 0, 0, -1, -3.9, 0, -0.1, 0, 0, 1, 0, 0, 0, 0, -5, 3, 0, 0, 0, 0, 0, 1, -3.9, 0, -1.1, 0, 0, -1, 0, 0, 0, 0, -5, 3 ]
    ac_21 = [
        0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, -1, 9.9, 1.1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, -9.9, -1.1, 0, 1, 0, 0, 0, 0 ]
    ac_22 = [
        0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, -0.5, 0, 0.866025403784, 0, 1.5, 0, -0.866025403784, 0, -0.5, 0, 0.866025403784, 0, -0.5, 0, -0.866025403784, 0, 1.5, 0, 0.866025403784, 0, -0.5, 0, -0.866025403784, 0, 0.5, 0, 0.866025403784, 0, 0, 0, 0.866025403784, 0, -0.5, 0, 0, 0, -1, 0, 0, 0, 1.5, 0, 0, 0, 1, 0, 0.866025403784, 0, 0.5, 0, -0.866025403784, 0, 0, 0, -0.866025403784, 0, -0.5, 0, 1.73205080757 ]
    ac_23 = [
        1, 0, 0, 0, 1, 0, 0.5, -0.866025403784, 0, 0.866025403784, 0.5, 0, -0.5, -0.866025403784, 0, 0.866025403784, -0.5, 0, -1, 0, 0, 0, -1, 0, -0.5, 0.866025403784, 0, -0.866025403784, -0.5, 0, 0.5, 0.866025403784, 0, -0.866025403784, 0.5, 0 ]
    ac_24 = [
        1, 0, 0, 0, 1, 0, -0.5, -0.866025403784, 1.5, 0.866025403784, -0.5, -0.866025403784, -0.5, 0.866025403784, 1.5, -0.866025403784, -0.5, 0.866025403784, 0.5, 0.866025403784, 0, 0.866025403784, -0.5, 0, 0.5, -0.866025403784, 0, -0.866025403784, -0.5, 1.73205080757, -1, 0, 1.5, 0, 1, 0.866025403784 ]
    ac_25 = [
        1, 0, 0, 0, 1, 0, -0.5, 0.866025403784, 0.75, -0.866025403784, -0.5, 0.433012701892, -0.5, -0.866025403784, 0.75, 0.866025403784, -0.5, -0.433012701892 ]
    ac_26 = [
        1, 0, 0, 0, 1, 0, 0.5, -0.866025403784, 0.75, 0.866025403784, 0.5, 0.433012701892, -0.5, -0.866025403784, 0.75, 0.866025403784, -0.5, 1.29903810568 ]
    ac_27 = [
        1, 0, 0, 0, 1, 0, 0.5, 0.866025403784, 0.75, 0.866025403784, -0.5, 0.433012701892, -0.5, -0.866025403784, 0.75, 0.866025403784, -0.5, -0.433012701892 ]
    ac_28 = [
        1, 0, 0, 0, 1, 0, -0.5, -0.866025403784, 0.75, -0.866025403784, 0.5, 0.433012701892, -0.5, 0.866025403784, 0.75, 0.866025403784, 0.5, -0.433012701892 ]
    ac_29 = [
        1, 0, 0, 0, 1, 0, -0.5, 0.866025403784, -0.5, -0.866025403784, -0.5, 0.866025403784, -0.5, -0.866025403784, 0.5, 0.866025403784, -0.5, 0.866025403784, -0.5, 0.866025403784, -1.5, 0.866025403784, 0.5, 0.866025403784, -0.5, -0.866025403784, -0.5, -0.866025403784, 0.5, 0.866025403784, 1, 0, -1, 0, -1, 1.73205080757 ]
    ac_30 = [
        1, 0, 0, 0, 1, 0, -0.5, 0.866025403784, -0.5, -0.866025403784, -0.5, 0.866025403784, -0.5, -0.866025403784, 0.5, 0.866025403784, -0.5, 0.866025403784, 0.5, -0.866025403784, -0.5, 0.866025403784, 0.5, 0.866025403784, 0.5, 0.866025403784, -1.5, -0.866025403784, 0.5, 0.866025403784, -1, 0, -1, 0, -1, 1.73205080757 ]
    ac_31 = [
        1, 0, 0, 0, 1, 0, -0.5, -0.866025403784, 0.5, 0.866025403784, -0.5, 0.866025403784, -0.5, 0.866025403784, -0.5, -0.866025403784, -0.5, 0.866025403784, 0.5, 0.866025403784, 0.5, -0.866025403784, 0.5, 0.866025403784, 0.5, -0.866025403784, 1.5, 0.866025403784, 0.5, 0.866025403784, -1, 0, 1, 0, -1, 1.73205080757 ]
    ac_32 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 7.8, 0, 0.2, 0, 0, 0, 0, 0, 1, 0, 0, 0 ]
    ac_33 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 3.9, 0, 0.1, 0, 0, 0, 0, 0, -1, 0, 5, -1.5 ]
    ac_34 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 5, 0, -1, 0, 0, 0, 0, 0, 1, 0, -3.9, -0.1 ]
    ac_35 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, -3.45, 4, 0, 0, 0, 0, 0, -1, 3.9, 0, 0.1 ]
    ac_36 = [
        0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0 ]
    ac_37 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 7.8, 0, 0.2, 0, 0, 0, 0, 0, -1, 0, 10, -4 ]
    ac_38 = [
        0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, -5, 3.9, 3.6, 0, 0, 0, 0, 0, 0, 0, -1, 3.9, 0, 0, 0.1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, -5, 3.9, 3.6, 0, 0, 0, 0, 0, 0, 0, 1, 3.9, 0, 0, 0.1 ]
    ac_39 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 1, 0, 0, -1, 0, 0, 0, 7.8, 0, 0.2, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, -7.8, 0, -0.2, 0, 0, 0, 0, 0, -1, 0, 0, 1 ]
    ac_40 = [
        0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 10, 0, -5, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 10, -5, 0, 0, 0, -1, 0, 0, 0, 0, 0, 10, 0, -4, 0, 0, 0, 0, 0, 0, 0, 1, -10, 0, -10, 10, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, -1, -10, 0, 0, 5 ]
    ac_41 = [
        0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 2, 0, 0, 0, -1, 0, 0, 0, -1, 0, 0, 0, 1, 0, 0, 0, 1, -3.9, -0.1, 0, 1, 0, 0, 0, 1, 0, 0, 0, -1, 3.9, 0.1 ]
    ac_42 = [
        0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 5, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, -1, 0, -3.9, 0, -0.1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0.5, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 3.9, 0.1, 0, 0, 0, -1, 0, 0, 0, 0, 5, 0, 0, -2.5, 0, 0, 0, 0, 0, 0, 0, 1, 0, -3.9, -3.9, -0.2 ]
    ac_43 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 3.9, 0, 0.1, 0, 0, 0, 0, 0, -1, 0, 3.9, 1.1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, -3.9, 0, -0.1, 0, 0, 0, 0, 0, -1, 0, 3.9, 1.1 ]
    ac_44 = [
        1, 0, 0, 0, 1, 0, 0, 1, 0, -1, 0, 2, -1, 0, 2, 0, -1, 2, 0, -1, 2, 1, 0, 0 ]
    ac_45 = [
        0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 2, 0, -1, 0, 0, 0, 2, 0, 0, 0, -1, 0, 2, 0, 0, 0, -1, 0, 2, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 4, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 2, 0, -1, 0, 0, 0, 2, 0, 0, 0, 1, 0, 2, 0, 0, 0, -1, 0, 2, 0, -1, 0, 0, 0, 4 ]
    ac_46 = [
        0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 3.8, 0.1, 0, 0, 0, -1, -3.8, 0.9 ]
    ac_47 = [
        1, 0, 0, 0, 1, 0, 0, -1, 2, 1, 0, 0 ]
    ac_48 = [
        0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0 ]
    ac_49 = [
        0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 2, 0, 0, 0, -1, 3.9, 0.1 ]
    ac_50 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, -3.45, 5, 0, 0, 0, 0, 0, -1, 3.9, 0, 0.1 ]
    ac_51 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 5, 0, -1, 0, 0, 0, 0, 0, -1, 0, -3.9, -0.1 ]
    ac_52 = [
        1, 0, 0, 0, 1, 0, 0, -1, 2, 1, 0, 0, -1, 0, 2, 0, -1, 2, 0, 1, 0, -1, 0, 2 ]
    ac_53 = [
        1, 0, 0, 0, 1, 0, 0.5, 0.866025403784, -0.866025403784, -0.866025403784, 0.5, 0.5, -0.5, 0.866025403784, -0.866025403784, -0.866025403784, -0.5, 1.5, -1, 0, 0, 0, -1, 2, -0.5, -0.866025403784, 0.866025403784, 0.866025403784, -0.5, 1.5, 0.5, -0.866025403784, 0.866025403784, 0.866025403784, 0.5, 0.5, -1, 0, 0, 0, 1, 0, -0.5, 0.866025403784, -0.866025403784, 0.866025403784, 0.5, 0.5, 0.5, 0.866025403784, -0.866025403784, 0.866025403784, -0.5, 1.5, 1, 0, 0, 0, -1, 2, 0.5, -0.866025403784, 0.866025403784, -0.866025403784, -0.5, 1.5, -0.5, -0.866025403784, 0.866025403784, -0.866025403784, 0.5, 0.5 ]
    ac_54 = [
        0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 1, 0, 0, 0, -1, 3.9, 0.1, 0, -1, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, -1, 3.9, 0.1 ]
    ac_55 = [
        1, 0, 0, 0, 1, 0, 0, 1, 0, -1, 0, 1, -1, 0, 1, 0, -1, 1, 0, -1, 1, 1, 0, 0 ]
    ac_56 = [
        1, 0, 0, 0, 1, 0, 0, 1, 0, -1, 0, 1, -1, 0, 1, 0, -1, 1, 0, -1, 1, 1, 0, 0, -1, 0, 0, 0, 1, 0, 0, -1, 0, -1, 0, 1, 1, 0, -1, 0, -1, 1, 0, 1, -1, 1, 0, 0 ]
    ac_57 = [
        1, 0, 0, 0, 1, 0, 0, -1, 1, 1, 0, 0, -1, 0, 1, 0, -1, 1, 0, 1, 0, -1, 0, 1 ]
    ac_58 = [
        0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0 ]
    ac_59 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0 ]
    ac_60 = [
        0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 5, 0, -1, 0, 0, 0, 0, 0, -1, 0, 3.9, 0.1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 7.8, 0.2, 0, 0, -1, 0, 0, 0, 5, 0, -1, 0, 0, 0, 0, 0, 1, 0, 3.9, 0.1 ]
    ac_61 = [
        0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 1, 0, 0, 0, -1, 7.8, 0.2, 0, 1, 0, 0, 0, 0.5, 0, 0, 0, -1, 3.9, 0.1, 0, -1, 0, 0, 0, 1.5, 0, 0, 0, 1, 3.9, 0.1 ]
    ac_62 = [
        1, 0, 0, 0, 1, 0, 0.5, -0.866025403784, 0.5, 0.866025403784, 0.5, 0.866025403784, -0.5, -0.866025403784, 0, 0.866025403784, -0.5, 1.73205080757, -1, 0, -1, 0, -1, 1.73205080757, -0.5, 0.866025403784, -1.5, -0.866025403784, -0.5, 0.866025403784, 0.5, 0.866025403784, -1, -0.866025403784, 0.5, 0 ]
    ac_63 = [
        1, 0, 0, 0, 1, 0, -1, 0, 0.5, 0, -1, 0.866025403784 ]
    ac_64 = [
        0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0 ]

    c_00 = [ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 2, 0, 1, 3 ]
    c_01 = [ 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 1, 2, 3 ]
    c_02 = [ 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 2, 0, 1, 3 ]
    c_03 = [ 0, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 2, 0, 1, 3 ]
    c_04 = [ 0, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 1, 2, 3 ]
    c_05 = [ 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 1, 2, 3 ]
    c_06 = [ 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 2, 3 ]
    c_07 = [ 0, 1, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 1, 2, 0, 2, 0, 1, 3 ]
    c_08 = [ 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 2, 0, 1, 3 ]
    c_09 = [ 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 1, 2, 0, 3 ]
    c_10 = [ 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 2, 3 ]
    c_11 = [ 0, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 2, 0, 3 ]
    c_12 = [ 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 1, 2, 3 ]
    c_13 = [ 0, 1, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 2, 0, 1, 3 ]
    c_14 = [ 0, 1, 2, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 1, 2, 3 ]
    c_15 = [ 0, 2, 1, 1, 0, 2, 0, 0, 0, 0, 0, 0, 1, 2, 0, 2, 0, 1, 3 ]
    c_16 = [ 0, 2, 1, 0, 1, 2, 0, 0, 0, 0, 0, 0, 2, 0, 1, 1, 2, 0, 3 ]
    c_17 = [ 1, 0, 2, 2, 0, 1, 0, 0, 0, 0, 0, 0, 1, 2, 0, 2, 0, 1, 3 ]
    c_18 = [ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 0, 2, 2 ]
    c_19 = [ 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 2, 2 ]
    c_20 = [ 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 1, 2, 2 ]
    c_21 = [ 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 1, 2, 2 ]
    c_22 = [ 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 2, 2 ]
    c_23 = [ 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 1, 2, 2 ]
    c_24 = [ 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 1, 2, 2 ]
    c_25 = [ 0, 1, 0, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 1, 2, 0, 1, 2, 2 ]
    c_26 = [ 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0, 1, 2, 0, 1, 2, 2 ]
    c_27 = [ 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 0, 2, 2 ]
    c_28 = [ 0, 1, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 1, 2, 2 ]

    _data = [
        # IH00 is undefined
        None,

        # IH01
        {
            "num_params": 4,
            "num_aspects": 1,
            "num_vertices": 6,
            "num_edge_shapes": 3,
            "edge_shapes": es_00,
            "edge_orientations": eo_00,
            "edge_shape_ids": esi_00,
            "default_params": dp_00,
            "vertex_coeffs": tvc_00,
            "translation_coeffs": tc_00,
            "aspect_coeffs": ac_00,
            "coloring": c_00
        },

        # IH02
        {
            "num_params": 4,
            "num_aspects": 2,
            "num_vertices": 6,
            "num_edge_shapes": 3,
            "edge_shapes": es_00,
            "edge_orientations": eo_01,
            "edge_shape_ids": esi_01,
            "default_params": dp_01,
            "vertex_coeffs": tvc_01,
            "translation_coeffs": tc_01,
            "aspect_coeffs": ac_01,
            "coloring": c_01
        },

        # IH03
        {
            "num_params": 4,
            "num_aspects": 2,
            "num_vertices": 6,
            "num_edge_shapes": 3,
            "edge_shapes": es_00,
            "edge_orientations": eo_02,
            "edge_shape_ids": esi_02,
            "default_params": dp_02,
            "vertex_coeffs": tvc_02,
            "translation_coeffs": tc_02,
            "aspect_coeffs": ac_02,
            "coloring": c_02
        },

        # IH04
        {
            "num_params": 6,
            "num_aspects": 2,
            "num_vertices": 6,
            "num_edge_shapes": 5,
            "edge_shapes": es_01,
            "edge_orientations": eo_03,
            "edge_shape_ids": esi_03,
            "default_params": dp_03,
            "vertex_coeffs": tvc_03,
            "translation_coeffs": tc_03,
            "aspect_coeffs": ac_03,
            "coloring": c_02
        },

        # IH05
        {
            "num_params": 5,
            "num_aspects": 4,
            "num_vertices": 6,
            "num_edge_shapes": 4,
            "edge_shapes": es_02,
            "edge_orientations": eo_04,
            "edge_shape_ids": esi_04,
            "default_params": dp_04,
            "vertex_coeffs": tvc_04,
            "translation_coeffs": tc_04,
            "aspect_coeffs": ac_04,
            "coloring": c_03
        },

        # IH06
        {
            "num_params": 5,
            "num_aspects": 4,
            "num_vertices": 6,
            "num_edge_shapes": 4,
            "edge_shapes": es_03,
            "edge_orientations": eo_05,
            "edge_shape_ids": esi_05,
            "default_params": dp_05,
            "vertex_coeffs": tvc_05,
            "translation_coeffs": tc_05,
            "aspect_coeffs": ac_05,
            "coloring": c_04
        },

        # IH07
        {
            "num_params": 2,
            "num_aspects": 3,
            "num_vertices": 6,
            "num_edge_shapes": 3,
            "edge_shapes": es_00,
            "edge_orientations": eo_06,
            "edge_shape_ids": esi_06,
            "default_params": dp_06,
            "vertex_coeffs": tvc_06,
            "translation_coeffs": tc_06,
            "aspect_coeffs": ac_06,
            "coloring": c_05
        },

        # IH08
        {
            "num_params": 4,
            "num_aspects": 1,
            "num_vertices": 6,
            "num_edge_shapes": 3,
            "edge_shapes": es_04,
            "edge_orientations": eo_07,
            "edge_shape_ids": esi_00,
            "default_params": dp_00,
            "vertex_coeffs": tvc_00,
            "translation_coeffs": tc_00,
            "aspect_coeffs": ac_00,
            "coloring": c_00
        },

        # IH09
        {
            "num_params": 3,
            "num_aspects": 2,
            "num_vertices": 6,
            "num_edge_shapes": 2,
            "edge_shapes": es_05,
            "edge_orientations": eo_08,
            "edge_shape_ids": esi_07,
            "default_params": dp_07,
            "vertex_coeffs": tvc_07,
            "translation_coeffs": tc_07,
            "aspect_coeffs": ac_07,
            "coloring": c_06
        },

        # IH10
        {
            "num_params": 0,
            "num_aspects": 1,
            "num_vertices": 6,
            "num_edge_shapes": 1,
            "edge_shapes": es_06,
            "edge_orientations": eo_06,
            "edge_shape_ids": esi_08,
            "default_params": dp_08,
            "vertex_coeffs": tvc_08,
            "translation_coeffs": tc_08,
            "aspect_coeffs": ac_08,
            "coloring": c_00
        },

        # IH11
        {
            "num_params": 0,
            "num_aspects": 1,
            "num_vertices": 6,
            "num_edge_shapes": 1,
            "edge_shapes": es_07,
            "edge_orientations": eo_07,
            "edge_shape_ids": esi_08,
            "default_params": dp_08,
            "vertex_coeffs": tvc_08,
            "translation_coeffs": tc_09,
            "aspect_coeffs": ac_08,
            "coloring": c_00
        },

        # IH12
        {
            "num_params": 2,
            "num_aspects": 1,
            "num_vertices": 6,
            "num_edge_shapes": 2,
            "edge_shapes": es_08,
            "edge_orientations": eo_09,
            "edge_shape_ids": esi_07,
            "default_params": dp_09,
            "vertex_coeffs": tvc_09,
            "translation_coeffs": tc_10,
            "aspect_coeffs": ac_09,
            "coloring": c_00
        },

        # IH13
        {
            "num_params": 3,
            "num_aspects": 2,
            "num_vertices": 6,
            "num_edge_shapes": 3,
            "edge_shapes": es_09,
            "edge_orientations": eo_10,
            "edge_shape_ids": esi_09,
            "default_params": dp_10,
            "vertex_coeffs": tvc_10,
            "translation_coeffs": tc_11,
            "aspect_coeffs": ac_10,
            "coloring": c_06
        },

        # IH14
        {
            "num_params": 2,
            "num_aspects": 1,
            "num_vertices": 6,
            "num_edge_shapes": 2,
            "edge_shapes": es_10,
            "edge_orientations": eo_11,
            "edge_shape_ids": esi_10,
            "default_params": dp_09,
            "vertex_coeffs": tvc_11,
            "translation_coeffs": tc_12,
            "aspect_coeffs": ac_09,
            "coloring": c_00
        },

        # IH15
        {
            "num_params": 3,
            "num_aspects": 2,
            "num_vertices": 6,
            "num_edge_shapes": 3,
            "edge_shapes": es_11,
            "edge_orientations": eo_12,
            "edge_shape_ids": esi_11,
            "default_params": dp_11,
            "vertex_coeffs": tvc_12,
            "translation_coeffs": tc_13,
            "aspect_coeffs": ac_11,
            "coloring": c_06
        },

        # IH16
        {
            "num_params": 1,
            "num_aspects": 3,
            "num_vertices": 6,
            "num_edge_shapes": 2,
            "edge_shapes": es_12,
            "edge_orientations": eo_13,
            "edge_shape_ids": esi_12,
            "default_params": dp_12,
            "vertex_coeffs": tvc_13,
            "translation_coeffs": tc_14,
            "aspect_coeffs": ac_12,
            "coloring": c_05
        },

        # IH17
        {
            "num_params": 2,
            "num_aspects": 1,
            "num_vertices": 6,
            "num_edge_shapes": 2,
            "edge_shapes": es_13,
            "edge_orientations": eo_14,
            "edge_shape_ids": esi_07,
            "default_params": dp_09,
            "vertex_coeffs": tvc_09,
            "translation_coeffs": tc_10,
            "aspect_coeffs": ac_09,
            "coloring": c_00
        },

        # IH18
        {
            "num_params": 0,
            "num_aspects": 1,
            "num_vertices": 6,
            "num_edge_shapes": 1,
            "edge_shapes": es_14,
            "edge_orientations": eo_06,
            "edge_shape_ids": esi_08,
            "default_params": dp_08,
            "vertex_coeffs": tvc_08,
            "translation_coeffs": tc_09,
            "aspect_coeffs": ac_08,
            "coloring": c_00
        },

        # IH19 is undefined
        None,

        # IH20
        {
            "num_params": 0,
            "num_aspects": 1,
            "num_vertices": 6,
            "num_edge_shapes": 1,
            "edge_shapes": es_15,
            "edge_orientations": eo_07,
            "edge_shape_ids": esi_08,
            "default_params": dp_08,
            "vertex_coeffs": tvc_08,
            "translation_coeffs": tc_09,
            "aspect_coeffs": ac_08,
            "coloring": c_00
        },

        # IH21
        {
            "num_params": 2,
            "num_aspects": 6,
            "num_vertices": 5,
            "num_edge_shapes": 3,
            "edge_shapes": es_16,
            "edge_orientations": eo_15,
            "edge_shape_ids": esi_13,
            "default_params": dp_13,
            "vertex_coeffs": tvc_14,
            "translation_coeffs": tc_15,
            "aspect_coeffs": ac_13,
            "coloring": c_07
        },

        # IH22
        {
            "num_params": 3,
            "num_aspects": 2,
            "num_vertices": 5,
            "num_edge_shapes": 3,
            "edge_shapes": es_17,
            "edge_orientations": eo_16,
            "edge_shape_ids": esi_14,
            "default_params": dp_14,
            "vertex_coeffs": tvc_15,
            "translation_coeffs": tc_16,
            "aspect_coeffs": ac_14,
            "coloring": c_06
        },

        # IH23
        {
            "num_params": 4,
            "num_aspects": 2,
            "num_vertices": 5,
            "num_edge_shapes": 4,
            "edge_shapes": es_18,
            "edge_orientations": eo_17,
            "edge_shape_ids": esi_15,
            "default_params": dp_15,
            "vertex_coeffs": tvc_16,
            "translation_coeffs": tc_17,
            "aspect_coeffs": ac_15,
            "coloring": c_08
        },

        # IH24
        {
            "num_params": 4,
            "num_aspects": 4,
            "num_vertices": 5,
            "num_edge_shapes": 4,
            "edge_shapes": es_19,
            "edge_orientations": eo_17,
            "edge_shape_ids": esi_15,
            "default_params": dp_15,
            "vertex_coeffs": tvc_16,
            "translation_coeffs": tc_18,
            "aspect_coeffs": ac_16,
            "coloring": c_09
        },

        # IH25
        {
            "num_params": 3,
            "num_aspects": 4,
            "num_vertices": 5,
            "num_edge_shapes": 3,
            "edge_shapes": es_20,
            "edge_orientations": eo_16,
            "edge_shape_ids": esi_14,
            "default_params": dp_14,
            "vertex_coeffs": tvc_15,
            "translation_coeffs": tc_19,
            "aspect_coeffs": ac_17,
            "coloring": c_10
        },

        # IH26
        {
            "num_params": 2,
            "num_aspects": 2,
            "num_vertices": 5,
            "num_edge_shapes": 3,
            "edge_shapes": es_21,
            "edge_orientations": eo_18,
            "edge_shape_ids": esi_14,
            "default_params": dp_16,
            "vertex_coeffs": tvc_17,
            "translation_coeffs": tc_20,
            "aspect_coeffs": ac_18,
            "coloring": c_01
        },

        # IH27
        {
            "num_params": 3,
            "num_aspects": 4,
            "num_vertices": 5,
            "num_edge_shapes": 3,
            "edge_shapes": es_16,
            "edge_orientations": eo_19,
            "edge_shape_ids": esi_16,
            "default_params": dp_17,
            "vertex_coeffs": tvc_18,
            "translation_coeffs": tc_21,
            "aspect_coeffs": ac_19,
            "coloring": c_11
        },

        # IH28
        {
            "num_params": 2,
            "num_aspects": 4,
            "num_vertices": 5,
            "num_edge_shapes": 3,
            "edge_shapes": es_16,
            "edge_orientations": eo_15,
            "edge_shape_ids": esi_13,
            "default_params": dp_18,
            "vertex_coeffs": tvc_19,
            "translation_coeffs": tc_22,
            "aspect_coeffs": ac_20,
            "coloring": c_12
        },

        # IH29
        {
            "num_params": 1,
            "num_aspects": 4,
            "num_vertices": 5,
            "num_edge_shapes": 2,
            "edge_shapes": es_12,
            "edge_orientations": eo_20,
            "edge_shape_ids": esi_17,
            "default_params": dp_19,
            "vertex_coeffs": tvc_20,
            "translation_coeffs": tc_23,
            "aspect_coeffs": ac_21,
            "coloring": c_04
        },

        # IH30
        {
            "num_params": 1,
            "num_aspects": 6,
            "num_vertices": 4,
            "num_edge_shapes": 3,
            "edge_shapes": es_22,
            "edge_orientations": eo_21,
            "edge_shape_ids": esi_18,
            "default_params": dp_20,
            "vertex_coeffs": tvc_21,
            "translation_coeffs": tc_24,
            "aspect_coeffs": ac_22,
            "coloring": c_13
        },

        # IH31
        {
            "num_params": 0,
            "num_aspects": 6,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_23,
            "edge_orientations": eo_22,
            "edge_shape_ids": esi_19,
            "default_params": dp_08,
            "vertex_coeffs": tvc_22,
            "translation_coeffs": tc_25,
            "aspect_coeffs": ac_23,
            "coloring": c_14
        },

        # IH32
        {
            "num_params": 0,
            "num_aspects": 6,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_24,
            "edge_orientations": eo_23,
            "edge_shape_ids": esi_19,
            "default_params": dp_08,
            "vertex_coeffs": tvc_22,
            "translation_coeffs": tc_26,
            "aspect_coeffs": ac_24,
            "coloring": c_15
        },

        # IH33
        {
            "num_params": 0,
            "num_aspects": 3,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_23,
            "edge_orientations": eo_22,
            "edge_shape_ids": esi_19,
            "default_params": dp_08,
            "vertex_coeffs": tvc_23,
            "translation_coeffs": tc_08,
            "aspect_coeffs": ac_25,
            "coloring": c_05
        },

        # IH34
        {
            "num_params": 0,
            "num_aspects": 3,
            "num_vertices": 4,
            "num_edge_shapes": 1,
            "edge_shapes": es_06,
            "edge_orientations": eo_24,
            "edge_shape_ids": esi_20,
            "default_params": dp_08,
            "vertex_coeffs": tvc_23,
            "translation_coeffs": tc_09,
            "aspect_coeffs": ac_26,
            "coloring": c_05
        },

        # IH35 is undefined
        None,

        # IH36
        {
            "num_params": 0,
            "num_aspects": 3,
            "num_vertices": 4,
            "num_edge_shapes": 1,
            "edge_shapes": es_06,
            "edge_orientations": eo_25,
            "edge_shape_ids": esi_20,
            "default_params": dp_08,
            "vertex_coeffs": tvc_23,
            "translation_coeffs": tc_08,
            "aspect_coeffs": ac_27,
            "coloring": c_05
        },

        # IH37
        {
            "num_params": 0,
            "num_aspects": 3,
            "num_vertices": 4,
            "num_edge_shapes": 1,
            "edge_shapes": es_15,
            "edge_orientations": eo_26,
            "edge_shape_ids": esi_20,
            "default_params": dp_08,
            "vertex_coeffs": tvc_23,
            "translation_coeffs": tc_08,
            "aspect_coeffs": ac_28,
            "coloring": c_05
        },

        # IH38
        {
            "num_params": 0,
            "num_aspects": 6,
            "num_vertices": 3,
            "num_edge_shapes": 2,
            "edge_shapes": es_10,
            "edge_orientations": eo_27,
            "edge_shape_ids": esi_21,
            "default_params": dp_08,
            "vertex_coeffs": tvc_24,
            "translation_coeffs": tc_27,
            "aspect_coeffs": ac_29,
            "coloring": c_15
        },

        # IH39
        {
            "num_params": 0,
            "num_aspects": 6,
            "num_vertices": 3,
            "num_edge_shapes": 2,
            "edge_shapes": es_25,
            "edge_orientations": eo_27,
            "edge_shape_ids": esi_21,
            "default_params": dp_08,
            "vertex_coeffs": tvc_24,
            "translation_coeffs": tc_28,
            "aspect_coeffs": ac_30,
            "coloring": c_16
        },

        # IH40
        {
            "num_params": 0,
            "num_aspects": 6,
            "num_vertices": 3,
            "num_edge_shapes": 2,
            "edge_shapes": es_24,
            "edge_orientations": eo_28,
            "edge_shape_ids": esi_21,
            "default_params": dp_08,
            "vertex_coeffs": tvc_24,
            "translation_coeffs": tc_29,
            "aspect_coeffs": ac_31,
            "coloring": c_17
        },

        # IH41
        {
            "num_params": 2,
            "num_aspects": 1,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_23,
            "edge_orientations": eo_22,
            "edge_shape_ids": esi_22,
            "default_params": dp_21,
            "vertex_coeffs": tvc_25,
            "translation_coeffs": tc_30,
            "aspect_coeffs": ac_09,
            "coloring": c_18
        },

        # IH42
        {
            "num_params": 2,
            "num_aspects": 2,
            "num_vertices": 4,
            "num_edge_shapes": 3,
            "edge_shapes": es_22,
            "edge_orientations": eo_29,
            "edge_shape_ids": esi_23,
            "default_params": dp_21,
            "vertex_coeffs": tvc_25,
            "translation_coeffs": tc_31,
            "aspect_coeffs": ac_32,
            "coloring": c_19
        },

        # IH43
        {
            "num_params": 2,
            "num_aspects": 2,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_23,
            "edge_orientations": eo_30,
            "edge_shape_ids": esi_22,
            "default_params": dp_21,
            "vertex_coeffs": tvc_25,
            "translation_coeffs": tc_31,
            "aspect_coeffs": ac_33,
            "coloring": c_19
        },

        # IH44
        {
            "num_params": 2,
            "num_aspects": 2,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_23,
            "edge_orientations": eo_31,
            "edge_shape_ids": esi_24,
            "default_params": dp_22,
            "vertex_coeffs": tvc_26,
            "translation_coeffs": tc_32,
            "aspect_coeffs": ac_34,
            "coloring": c_20
        },

        # IH45
        {
            "num_params": 2,
            "num_aspects": 2,
            "num_vertices": 4,
            "num_edge_shapes": 3,
            "edge_shapes": es_22,
            "edge_orientations": eo_32,
            "edge_shape_ids": esi_23,
            "default_params": dp_23,
            "vertex_coeffs": tvc_27,
            "translation_coeffs": tc_33,
            "aspect_coeffs": ac_35,
            "coloring": c_20
        },

        # IH46
        {
            "num_params": 4,
            "num_aspects": 2,
            "num_vertices": 4,
            "num_edge_shapes": 4,
            "edge_shapes": es_26,
            "edge_orientations": eo_33,
            "edge_shape_ids": esi_25,
            "default_params": dp_24,
            "vertex_coeffs": tvc_28,
            "translation_coeffs": tc_34,
            "aspect_coeffs": ac_36,
            "coloring": c_20
        },

        # IH47
        {
            "num_params": 2,
            "num_aspects": 2,
            "num_vertices": 4,
            "num_edge_shapes": 3,
            "edge_shapes": es_27,
            "edge_orientations": eo_29,
            "edge_shape_ids": esi_23,
            "default_params": dp_21,
            "vertex_coeffs": tvc_25,
            "translation_coeffs": tc_35,
            "aspect_coeffs": ac_37,
            "coloring": c_19
        },

        # IH48 is undefined
        None,

        # IH49
        {
            "num_params": 3,
            "num_aspects": 4,
            "num_vertices": 4,
            "num_edge_shapes": 4,
            "edge_shapes": es_28,
            "edge_orientations": eo_33,
            "edge_shape_ids": esi_25,
            "default_params": dp_25,
            "vertex_coeffs": tvc_29,
            "translation_coeffs": tc_36,
            "aspect_coeffs": ac_38,
            "coloring": c_21
        },

        # IH50
        {
            "num_params": 2,
            "num_aspects": 4,
            "num_vertices": 4,
            "num_edge_shapes": 3,
            "edge_shapes": es_29,
            "edge_orientations": eo_29,
            "edge_shape_ids": esi_23,
            "default_params": dp_21,
            "vertex_coeffs": tvc_25,
            "translation_coeffs": tc_37,
            "aspect_coeffs": ac_39,
            "coloring": c_22
        },

        # IH51
        {
            "num_params": 3,
            "num_aspects": 4,
            "num_vertices": 4,
            "num_edge_shapes": 3,
            "edge_shapes": es_27,
            "edge_orientations": eo_32,
            "edge_shape_ids": esi_23,
            "default_params": dp_26,
            "vertex_coeffs": tvc_30,
            "translation_coeffs": tc_38,
            "aspect_coeffs": ac_40,
            "coloring": c_21
        },

        # IH52
        {
            "num_params": 1,
            "num_aspects": 4,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_23,
            "edge_orientations": eo_34,
            "edge_shape_ids": esi_22,
            "default_params": dp_20,
            "vertex_coeffs": tvc_31,
            "translation_coeffs": tc_39,
            "aspect_coeffs": ac_41,
            "coloring": c_23
        },

        # IH53
        {
            "num_params": 3,
            "num_aspects": 4,
            "num_vertices": 4,
            "num_edge_shapes": 3,
            "edge_shapes": es_27,
            "edge_orientations": eo_35,
            "edge_shape_ids": esi_26,
            "default_params": dp_27,
            "vertex_coeffs": tvc_32,
            "translation_coeffs": tc_40,
            "aspect_coeffs": ac_42,
            "coloring": c_21
        },

        # IH54
        {
            "num_params": 2,
            "num_aspects": 4,
            "num_vertices": 4,
            "num_edge_shapes": 4,
            "edge_shapes": es_30,
            "edge_orientations": eo_33,
            "edge_shape_ids": esi_25,
            "default_params": dp_28,
            "vertex_coeffs": tvc_33,
            "translation_coeffs": tc_41,
            "aspect_coeffs": ac_43,
            "coloring": c_22
        },

        # IH55
        {
            "num_params": 0,
            "num_aspects": 4,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_23,
            "edge_orientations": eo_24,
            "edge_shape_ids": esi_24,
            "default_params": dp_08,
            "vertex_coeffs": tvc_34,
            "translation_coeffs": tc_42,
            "aspect_coeffs": ac_44,
            "coloring": c_24
        },

        # IH56
        {
            "num_params": 1,
            "num_aspects": 8,
            "num_vertices": 4,
            "num_edge_shapes": 3,
            "edge_shapes": es_22,
            "edge_orientations": eo_36,
            "edge_shape_ids": esi_26,
            "default_params": dp_29,
            "vertex_coeffs": tvc_35,
            "translation_coeffs": tc_43,
            "aspect_coeffs": ac_45,
            "coloring": c_25
        },

        # IH57
        {
            "num_params": 2,
            "num_aspects": 1,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_31,
            "edge_orientations": eo_33,
            "edge_shape_ids": esi_22,
            "default_params": dp_21,
            "vertex_coeffs": tvc_25,
            "translation_coeffs": tc_30,
            "aspect_coeffs": ac_09,
            "coloring": c_18
        },

        # IH58
        {
            "num_params": 2,
            "num_aspects": 2,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_32,
            "edge_orientations": eo_33,
            "edge_shape_ids": esi_22,
            "default_params": dp_21,
            "vertex_coeffs": tvc_25,
            "translation_coeffs": tc_31,
            "aspect_coeffs": ac_32,
            "coloring": c_19
        },

        # IH59
        {
            "num_params": 1,
            "num_aspects": 2,
            "num_vertices": 4,
            "num_edge_shapes": 1,
            "edge_shapes": es_06,
            "edge_orientations": eo_31,
            "edge_shape_ids": esi_20,
            "default_params": dp_30,
            "vertex_coeffs": tvc_36,
            "translation_coeffs": tc_44,
            "aspect_coeffs": ac_46,
            "coloring": c_20
        },

        # IH60 is undefined
        None,

        # IH61
        {
            "num_params": 0,
            "num_aspects": 2,
            "num_vertices": 4,
            "num_edge_shapes": 1,
            "edge_shapes": es_06,
            "edge_orientations": eo_24,
            "edge_shape_ids": esi_20,
            "default_params": dp_08,
            "vertex_coeffs": tvc_34,
            "translation_coeffs": tc_45,
            "aspect_coeffs": ac_47,
            "coloring": c_20
        },

        # IH62
        {
            "num_params": 0,
            "num_aspects": 1,
            "num_vertices": 4,
            "num_edge_shapes": 1,
            "edge_shapes": es_07,
            "edge_orientations": eo_33,
            "edge_shape_ids": esi_20,
            "default_params": dp_08,
            "vertex_coeffs": tvc_34,
            "translation_coeffs": tc_46,
            "aspect_coeffs": ac_08,
            "coloring": c_18
        },

        # IH63 is undefined
        None,

        # IH64
        {
            "num_params": 1,
            "num_aspects": 1,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_33,
            "edge_orientations": eo_37,
            "edge_shape_ids": esi_22,
            "default_params": dp_20,
            "vertex_coeffs": tvc_31,
            "translation_coeffs": tc_47,
            "aspect_coeffs": ac_48,
            "coloring": c_18
        },

        # IH65 is undefined
        None,

        # IH66
        {
            "num_params": 1,
            "num_aspects": 2,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_34,
            "edge_orientations": eo_37,
            "edge_shape_ids": esi_22,
            "default_params": dp_20,
            "vertex_coeffs": tvc_31,
            "translation_coeffs": tc_48,
            "aspect_coeffs": ac_49,
            "coloring": c_19
        },

        # IH67
        {
            "num_params": 2,
            "num_aspects": 2,
            "num_vertices": 4,
            "num_edge_shapes": 3,
            "edge_shapes": es_21,
            "edge_orientations": eo_38,
            "edge_shape_ids": esi_23,
            "default_params": dp_23,
            "vertex_coeffs": tvc_27,
            "translation_coeffs": tc_49,
            "aspect_coeffs": ac_50,
            "coloring": c_20
        },

        # IH68
        {
            "num_params": 1,
            "num_aspects": 1,
            "num_vertices": 4,
            "num_edge_shapes": 1,
            "edge_shapes": es_06,
            "edge_orientations": eo_39,
            "edge_shape_ids": esi_20,
            "default_params": dp_30,
            "vertex_coeffs": tvc_36,
            "translation_coeffs": tc_50,
            "aspect_coeffs": ac_48,
            "coloring": c_18
        },

        # IH69
        {
            "num_params": 2,
            "num_aspects": 2,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_31,
            "edge_orientations": eo_26,
            "edge_shape_ids": esi_24,
            "default_params": dp_22,
            "vertex_coeffs": tvc_26,
            "translation_coeffs": tc_32,
            "aspect_coeffs": ac_51,
            "coloring": c_20
        },

        # IH70 is undefined
        None,

        # IH71
        {
            "num_params": 0,
            "num_aspects": 4,
            "num_vertices": 4,
            "num_edge_shapes": 1,
            "edge_shapes": es_06,
            "edge_orientations": eo_40,
            "edge_shape_ids": esi_20,
            "default_params": dp_08,
            "vertex_coeffs": tvc_34,
            "translation_coeffs": tc_42,
            "aspect_coeffs": ac_52,
            "coloring": c_24
        },

        # IH72
        {
            "num_params": 1,
            "num_aspects": 1,
            "num_vertices": 4,
            "num_edge_shapes": 2,
            "edge_shapes": es_24,
            "edge_orientations": eo_33,
            "edge_shape_ids": esi_22,
            "default_params": dp_20,
            "vertex_coeffs": tvc_31,
            "translation_coeffs": tc_47,
            "aspect_coeffs": ac_48,
            "coloring": c_18
        },

        # IH73
        {
            "num_params": 0,
            "num_aspects": 2,
            "num_vertices": 4,
            "num_edge_shapes": 1,
            "edge_shapes": es_14,
            "edge_orientations": eo_24,
            "edge_shape_ids": esi_20,
            "default_params": dp_08,
            "vertex_coeffs": tvc_34,
            "translation_coeffs": tc_45,
            "aspect_coeffs": ac_47,
            "coloring": c_20
        },

        # IH74
        {
            "num_params": 1,
            "num_aspects": 1,
            "num_vertices": 4,
            "num_edge_shapes": 1,
            "edge_shapes": es_07,
            "edge_orientations": eo_26,
            "edge_shape_ids": esi_20,
            "default_params": dp_30,
            "vertex_coeffs": tvc_36,
            "translation_coeffs": tc_50,
            "aspect_coeffs": ac_48,
            "coloring": c_18
        },

        # IH75 is undefined
        None,

        # IH76
        {
            "num_params": 0,
            "num_aspects": 1,
            "num_vertices": 4,
            "num_edge_shapes": 1,
            "edge_shapes": es_15,
            "edge_orientations": eo_33,
            "edge_shape_ids": esi_20,
            "default_params": dp_08,
            "vertex_coeffs": tvc_34,
            "translation_coeffs": tc_46,
            "aspect_coeffs": ac_08,
            "coloring": c_18
        },

        # IH77
        {
            "num_params": 0,
            "num_aspects": 12,
            "num_vertices": 3,
            "num_edge_shapes": 3,
            "edge_shapes": es_35,
            "edge_orientations": eo_41,
            "edge_shape_ids": esi_27,
            "default_params": dp_08,
            "vertex_coeffs": tvc_37,
            "translation_coeffs": tc_51,
            "aspect_coeffs": ac_53,
            "coloring": c_26
        },

        # IH78
        {
            "num_params": 1,
            "num_aspects": 4,
            "num_vertices": 3,
            "num_edge_shapes": 3,
            "edge_shapes": es_36,
            "edge_orientations": eo_41,
            "edge_shape_ids": esi_27,
            "default_params": dp_20,
            "vertex_coeffs": tvc_38,
            "translation_coeffs": tc_52,
            "aspect_coeffs": ac_54,
            "coloring": c_22
        },

        # IH79
        {
            "num_params": 0,
            "num_aspects": 4,
            "num_vertices": 3,
            "num_edge_shapes": 2,
            "edge_shapes": es_25,
            "edge_orientations": eo_27,
            "edge_shape_ids": esi_21,
            "default_params": dp_08,
            "vertex_coeffs": tvc_39,
            "translation_coeffs": tc_53,
            "aspect_coeffs": ac_55,
            "coloring": c_27
        },

        # IH80 is undefined
        None,

        # IH81
        {
            "num_params": 0,
            "num_aspects": 8,
            "num_vertices": 3,
            "num_edge_shapes": 2,
            "edge_shapes": es_10,
            "edge_orientations": eo_27,
            "edge_shape_ids": esi_21,
            "default_params": dp_08,
            "vertex_coeffs": tvc_39,
            "translation_coeffs": tc_54,
            "aspect_coeffs": ac_56,
            "coloring": c_25
        },

        # IH82
        {
            "num_params": 0,
            "num_aspects": 4,
            "num_vertices": 3,
            "num_edge_shapes": 2,
            "edge_shapes": es_24,
            "edge_orientations": eo_28,
            "edge_shape_ids": esi_21,
            "default_params": dp_08,
            "vertex_coeffs": tvc_39,
            "translation_coeffs": tc_55,
            "aspect_coeffs": ac_57,
            "coloring": c_27
        },

        # IH83
        {
            "num_params": 1,
            "num_aspects": 2,
            "num_vertices": 3,
            "num_edge_shapes": 2,
            "edge_shapes": es_10,
            "edge_orientations": eo_42,
            "edge_shape_ids": esi_28,
            "default_params": dp_31,
            "vertex_coeffs": tvc_40,
            "translation_coeffs": tc_56,
            "aspect_coeffs": ac_58,
            "coloring": c_20
        },

        # IH84
        {
            "num_params": 2,
            "num_aspects": 2,
            "num_vertices": 3,
            "num_edge_shapes": 3,
            "edge_shapes": es_04,
            "edge_orientations": eo_41,
            "edge_shape_ids": esi_27,
            "default_params": dp_32,
            "vertex_coeffs": tvc_41,
            "translation_coeffs": tc_57,
            "aspect_coeffs": ac_59,
            "coloring": c_20
        },

        # IH85
        {
            "num_params": 2,
            "num_aspects": 4,
            "num_vertices": 3,
            "num_edge_shapes": 3,
            "edge_shapes": es_37,
            "edge_orientations": eo_41,
            "edge_shape_ids": esi_27,
            "default_params": dp_32,
            "vertex_coeffs": tvc_41,
            "translation_coeffs": tc_58,
            "aspect_coeffs": ac_60,
            "coloring": c_21
        },

        # IH86
        {
            "num_params": 1,
            "num_aspects": 4,
            "num_vertices": 3,
            "num_edge_shapes": 2,
            "edge_shapes": es_25,
            "edge_orientations": eo_42,
            "edge_shape_ids": esi_28,
            "default_params": dp_31,
            "vertex_coeffs": tvc_40,
            "translation_coeffs": tc_59,
            "aspect_coeffs": ac_61,
            "coloring": c_21
        },

        # IH87 is undefined
        None,

        # IH88
        {
            "num_params": 0,
            "num_aspects": 6,
            "num_vertices": 3,
            "num_edge_shapes": 2,
            "edge_shapes": es_25,
            "edge_orientations": eo_43,
            "edge_shape_ids": esi_28,
            "default_params": dp_08,
            "vertex_coeffs": tvc_42,
            "translation_coeffs": tc_60,
            "aspect_coeffs": ac_62,
            "coloring": c_28
        },

        # IH89 is undefined
        None,

        # IH90
        {
            "num_params": 0,
            "num_aspects": 2,
            "num_vertices": 3,
            "num_edge_shapes": 1,
            "edge_shapes": es_07,
            "edge_orientations": eo_41,
            "edge_shape_ids": esi_29,
            "default_params": dp_08,
            "vertex_coeffs": tvc_42,
            "translation_coeffs": tc_09,
            "aspect_coeffs": ac_63,
            "coloring": c_20
        },

        # IH91
        {
            "num_params": 1,
            "num_aspects": 2,
            "num_vertices": 3,
            "num_edge_shapes": 2,
            "edge_shapes": es_32,
            "edge_orientations": eo_44,
            "edge_shape_ids": esi_28,
            "default_params": dp_31,
            "vertex_coeffs": tvc_40,
            "translation_coeffs": tc_61,
            "aspect_coeffs": ac_64,
            "coloring": c_20
        },

        # IH92 is undefined
        None,

        # IH93
        {
            "num_params": 0,
            "num_aspects": 2,
            "num_vertices": 3,
            "num_edge_shapes": 1,
            "edge_shapes": es_15,
            "edge_orientations": eo_41,
            "edge_shape_ids": esi_29,
            "default_params": dp_08,
            "vertex_coeffs": tvc_42,
            "translation_coeffs": tc_09,
            "aspect_coeffs": ac_63,
            "coloring": c_20
        }

    ]

    _data = [Tile(**datum) if datum is not None else None for datum in _data]    

    @staticmethod
    def get_data(key):

        return TilingTypeData._data[key]
